import fs from "fs";
import { appLog } from "../utils/utils";
import { InitialData } from "./app-types";

const storagePath = "./storage/";
const storageFile = "storage.json";

export const saveInitialData = (initialData: InitialData): void => {
  if (!fs.existsSync(storagePath)) {
    fs.mkdirSync(storagePath);
  }
  fs.writeFileSync(storagePath + storageFile, JSON.stringify(initialData));
  appLog("Initial file saved/updated successfully");
};

export const getAccessToken = (): string => {
  return getInitialData().accessToken;
};

export const updateAccessToken = (accessToken: string): void => {
  let updatedInitialData: InitialData = getInitialData();
  updatedInitialData.accessToken = accessToken;
  appLog("Access token updated");
  saveInitialData(updatedInitialData);
};

export const getInitialData = (): InitialData => {
  return JSON.parse(
    fs.readFileSync(storagePath + storageFile).toString()
  ) as InitialData;
};
